@@ -1,11 +1,11 @@
-# -*- coding: utf-8 -*-
+# -*- coding: ascii -*-
 """
-Meta information about web2ldap
+web2ldap.__about__ -- Meta information about web2ldap
 
 web2ldap - a web-based LDAP Client,
 see https://www.web2ldap.de for details
 
-(c) 1998-2021 by Michael Stroeder <michael@stroeder.com>
+(C) 1998-2022 by Michael Stroeder <michael@stroeder.com>
 
 This software is distributed under the terms of the
 Apache License Version 2.0 (Apache-2.0)
@@ -17,13 +17,13 @@ import collections
 VersionInfo = collections.namedtuple('VersionInfo', ('major', 'minor', 'micro'))
 __version_info__ = VersionInfo(
     major=1,
-    minor=6,
-    micro=4,
+    minor=7,
+    micro=3,
 )
 __version__ = '.'.join(str(val) for val in __version_info__)
 __author__ = 'Michael Stroeder'
 __mail__ = 'michael@stroeder.com'
-__copyright__ = '(C) 2017-2021 by Michael Ströder <michael@stroeder.com>'
+__copyright__ = '(C) 1998-2022 by Michael Str\xf6der <michael@stroeder.com>'
 __license__ = 'Apache-2.0'
 
 __all__ = [
