@@ -1,11 +1,11 @@
-# -*- coding: utf-8 -*-
+# -*- coding: ascii -*-
 """
 web2ldap.app.handler: base handler
 
 web2ldap - a web-based LDAP Client,
 see https://www.web2ldap.de for details
 
-(c) 1998-2021 by Michael Stroeder <michael@stroeder.com>
+(C) 1998-2022 by Michael Stroeder <michael@stroeder.com>
 
 This software is distributed under the terms of the
 Apache License Version 2.0 (Apache-2.0)
@@ -250,7 +250,7 @@ class AppHandler(LogHelper):
             cfg_url = 'ldap://'
         return LDAP_DEF.get_param(
             cfg_url,
-            self.naming_context or u'',
+            self.naming_context or '',
             param_key,
             default,
         )
@@ -260,7 +260,7 @@ class AppHandler(LogHelper):
         """
         get parameter 'binddn_mapping' from cascaded configuration
         """
-        return self.cfg_param('binddn_mapping', u'ldap:///_??sub?(uid={user})')
+        return self.cfg_param('binddn_mapping', 'ldap:///_??sub?(uid={user})')
 
     def check_access(self, command):
         """
@@ -284,6 +284,7 @@ class AppHandler(LogHelper):
             target=None,
             title=None,
             anchor_id=None,
+            rel=None,
         ):
         """
         Build the HTML text of a anchor with form parameters
@@ -306,8 +307,12 @@ class AppHandler(LogHelper):
             title_attr = ' title="%s"' % (self.form.s2d(title).replace(' ', '&nbsp;'))
         if anchor_id:
             anchor_id = '#%s' % (self.form.s2d(anchor_id))
-        res = '<a class="CL"%s%s href="%s?%s%s">%s</a>' % (
+        rel_attr = ''
+        if rel:
+            rel_attr = ' rel="%s"' % (rel)
+        res = '<a class="CL"%s%s%s href="%s?%s%s">%s</a>' % (
             target_attr,
+            rel_attr,
             title_attr,
             self.form.action_url(command, self.sid),
             '&amp;'.join([
@@ -377,7 +382,7 @@ class AppHandler(LogHelper):
         """
         form_str = [self.begin_form(command, method, target)]
         for param_name, param_value in form_parameters:
-            form_str.append(self.form.hidden_field_html(param_name, param_value, u''))
+            form_str.append(self.form.hidden_field_html(param_name, param_value, ''))
         form_str.append(
             '<p>\n<input type="submit" value="%s">\n%s\n</p>\n</form>' % (
                 submitstr,
@@ -422,24 +427,20 @@ class AppHandler(LogHelper):
         path_info = env.get('PATH_INFO', '/')[1:]
         self.log(logging.DEBUG, 'splitting path_info %r', path_info)
         if not path_info:
-            cmd, sid = '', ''
+            sid, cmd = '', ''
         else:
-            # Work around broken web servers which adds the script name
-            # to path info as well
-            script_name = env['SCRIPT_NAME']
-            if path_info.startswith(script_name):
-                path_info = path_info[len(script_name):]
             try:
-                cmd, sid = path_info.split('/', 1)
+                sid, cmd = path_info.split('/', 1)
             except ValueError:
-                cmd, sid = path_info, ''
-        self.log(logging.DEBUG, 'split path_info to (%r, %r)', cmd, sid)
-        return cmd, sid # path_info()
+                sid, cmd = '', path_info
+        self.log(logging.DEBUG, 'split path_info to (%r, %r)', sid, cmd)
+        return cmd, sid
+        # path_info()
 
     def display_dn(self, dn, links=False):
         """Display a DN as LDAP URL with or without button"""
         assert isinstance(dn, str), TypeError("Argument 'dn' must be str, was %r" % (dn,))
-        dn_str = self.form.s2d(dn or u'- World -')
+        dn_str = self.form.s2d(dn or '- World -')
         if links:
             command_buttons = [
                 dn_str,
@@ -490,8 +491,8 @@ class AppHandler(LogHelper):
 
     def simple_message(
             self,
-            title=u'',
-            message=u'',
+            title='',
+            message='',
             main_div_id='Message',
             main_menu_list=None,
             context_menu_list=None,
@@ -528,7 +529,7 @@ class AppHandler(LogHelper):
             self.form = Web2LDAPForm(None, self.env)
         target_url = target_url or self.script_name
         url_redirect_template_str = read_template(
-            self, None, u'redirect',
+            self, None, 'redirect',
             tmpl_filename=web2ldapcnf.redirect_template,
         )
         if refresh_time:
@@ -558,7 +559,7 @@ class AppHandler(LogHelper):
             web2ldapcnf.ldap_trace_level,
             web2ldapcnf.ldap_cache_ttl,
         )
-        self.ls.cookie = self.form.set_cookie(str(id(self.ls)))
+        self.ls.cookie = self.form.set_cookie(self.sid, str(id(self.ls)))
         self._session_store.save(self.sid, self.ls)
         # end of _get_session()
 
@@ -648,7 +649,7 @@ class AppHandler(LogHelper):
                     input_ldapurl = ExtendedLDAPUrl(ldap_url_input)
                 except ValueError as err:
                     raise ErrorExit(
-                        u'Error parsing LDAP URL: %s.' % (err,)
+                        'Error parsing LDAP URL: %s.' % (err,)
                     )
             else:
                 input_ldapurl = ExtendedLDAPUrl()
@@ -724,17 +725,17 @@ class AppHandler(LogHelper):
         """
         matched_dn = None
         if isinstance(ldap_err, ldap0.TIMEOUT) or not ldap_err.args:
-            error_msg = u''
+            error_msg = ''
         elif isinstance(ldap_err, ldap0.INVALID_CREDENTIALS) and \
             AD_LDAP49_ERROR_PREFIX in ldap_err.args[0].get('info', b''):
             ad_error_code_pos = (
                 ldap_err.args[0]['info'].find(AD_LDAP49_ERROR_PREFIX)+len(AD_LDAP49_ERROR_PREFIX)
             )
             ad_error_code = int(ldap_err.args[0]['info'][ad_error_code_pos:ad_error_code_pos+3], 16)
-            error_msg = u'%s:\n%s (%s)' % (
+            error_msg = '%s:\n%s (%s)' % (
                 ldap_err.args[0]['desc'].decode(self.ls.charset),
                 ldap_err.args[0].get('info', b'').decode(self.ls.charset),
-                AD_LDAP49_ERROR_CODES.get(ad_error_code, u'unknown'),
+                AD_LDAP49_ERROR_CODES.get(ad_error_code, 'unknown'),
             )
         else:
             try:
@@ -1008,8 +1009,8 @@ class AppHandler(LogHelper):
             log_exception(self.env, self.ls, self.dn, web2ldapcnf.log_error_details)
             exception_message(
                 self,
-                u'Error parsing form',
-                u'Error parsing form:<br>%s' % (
+                'Error parsing form',
+                'Error parsing form:<br>%s' % (
                     self.form.s2d(str(form_error)),
                 ),
             )
@@ -1046,7 +1047,7 @@ class AppHandler(LogHelper):
                 self.dn = ldap_err.args[0]['matched'].decode(self.ls.charset)
             exception_message(
                 self,
-                u'No such object',
+                'No such object',
                 self.ldap_error_msg(
                     ldap_err,
                     template='{{error_msg}}<br>{0}{{matched_dn}}'.format(
@@ -1058,49 +1059,43 @@ class AppHandler(LogHelper):
         except (ldap0.PARTIAL_RESULTS, ldap0.REFERRAL) as err:
             w2l_chasereferral(self, err)
 
+        except InvalidSimpleBindDN as err:
+            w2l_login(
+                self,
+                who='',
+                login_msg=self.form.s2d(str(err)),
+                relogin=True,
+            )
+
         except (
                 ldap0.INSUFFICIENT_ACCESS,
                 ldap0.STRONG_AUTH_REQUIRED,
                 ldap0.INAPPROPRIATE_AUTH,
-                UsernameNotFound,
+                ldap0.INVALID_CREDENTIALS,
             ) as err:
             log_exception(self.env, self.ls, self.dn, web2ldapcnf.log_error_details)
             w2l_login(
                 self,
-                who=u'',
                 login_msg=self.ldap_error_msg(err),
+                who=who,
                 relogin=True,
             )
 
-        except ldap0.INVALID_CREDENTIALS as err:
-            w2l_login(
-                self,
-                login_msg=self.ldap_error_msg(err),
-                who=who, relogin=True,
-            )
-
-        except (InvalidSimpleBindDN, UsernameNotUnique) as err:
-            w2l_login(
-                self,
-                login_msg=self.form.s2d(str(err)),
-                who=who, relogin=True,
-            )
-
         except PasswordPolicyExpirationWarning as err:
             # Setup what's required for executing command 'passwd'
             self.dn = self.ls.l.whoami_s()[3:] or err.who
             # Output the change password form
             passwd.passwd_form(
                 self,
-                u'',
+                '',
                 self.dn,
                 None,
                 'Password change needed',
                 self.form.s2d(
-                    u'Password will expire in %s!' % (
+                    'Password will expire in %s!' % (
                         ts2repr(
                             Timespan.time_divisors,
-                            u' ',
+                            ' ',
                             err.timeBeforeExpiration,
                         )
                     )
@@ -1113,7 +1108,7 @@ class AppHandler(LogHelper):
             # Output the change password form
             passwd.passwd_form(
                 self,
-                u'',
+                '',
                 self.dn,
                 None,
                 'Password change needed',
@@ -1124,7 +1119,7 @@ class AppHandler(LogHelper):
             log_exception(self.env, self.ls, self.dn, web2ldapcnf.log_error_details)
             exception_message(
                 self,
-                u'Unhandled %s' % err.__class__.__name__,
+                'Unhandled %s' % err.__class__.__name__,
                 self.form.s2d(str(err)),
             )
 
@@ -1132,7 +1127,7 @@ class AppHandler(LogHelper):
             log_exception(self.env, self.ls, self.dn, web2ldapcnf.log_error_details)
             exception_message(
                 self,
-                u'Unhandled %s' % ldap_err.__class__.__name__,
+                'Unhandled %s' % ldap_err.__class__.__name__,
                 self.ldap_error_msg(ldap_err),
             )
 
@@ -1143,7 +1138,7 @@ class AppHandler(LogHelper):
         except MaxSessionPerIPExceeded as session_err:
             self.log(logging.WARN, str(session_err))
             self.simple_msg(
-                u'Client %s exceeded limit of max. %d sessions! Try later...' % (
+                'Client %s exceeded limit of max. %d sessions! Try later...' % (
                     session_err.remote_ip,
                     session_err.max_session_count,
                 )
