@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# -*- coding: ascii -*-
 """
 web2ldap plugin classes for Active Directory (for some information see draft-armijo-ldap-syntax)
 """
@@ -8,6 +8,8 @@ import time
 import uuid
 from typing import Dict
 
+import iso3166
+
 from ldap0.dn import is_dn
 from ldap0.msad import sid2sddl, sddl2sid
 
@@ -59,7 +61,7 @@ class ObjectVersion(Integer, SelectList):
     desc: str = 'Object version in MS AD (see [MS-ADTS])'
     attr_value_dict: Dict[str, str] = {
         '13': 'Windows 2000 Server operating system',
-        '30': 'Windows Server 2003 operating system or Windows Server 2008 (AD LDS)',
+        '30': 'Windows Server 2003 operating system or Windows Server 2008 (AD LDS)',
         '31': 'Windows Server 2003 R2 operating system or Windows Server 2008 R2 (AD LDS)',
         '44': 'Windows Server 2008 operating system (AD DS)',
         '47': 'Windows Server 2008 R2 (AD DS)',
@@ -494,12 +496,9 @@ syntax_registry.reg_at(
 )
 
 
-class CountryCode(PropertiesSelectList):
+class CountryCode(SelectList):
     oid: str = 'CountryCode-oid'
     desc: str = 'Numerical country code'
-    properties_pathname = os.path.join(
-        ETC_DIR, 'properties', 'attribute_select_countryCode.properties'
-    )
     sani_funcs = (
         bytes.strip,
     )
@@ -507,8 +506,10 @@ class CountryCode(PropertiesSelectList):
     def get_attr_value_dict(self) -> Dict[str, str]:
         # Enable empty value in any case
         attr_value_dict: Dict[str, str] = {'0': '-/-'}
-        attr_value_dict.update(PropertiesSelectList.get_attr_value_dict(self))
-        del attr_value_dict['']
+        attr_value_dict.update({
+            str(int(num)): cty.name  for num, cty in iso3166.countries_by_numeric.items()
+        })
+        attr_value_dict.pop('', None)
         return attr_value_dict
 
 
@@ -673,6 +674,8 @@ class DomainFunctionality(SelectList):
         '3': 'Windows 2008',
         '4': 'Windows 2008R2',
         '5': 'Windows 2012',
+        '6': 'Windows 2012R2',
+        '7': 'Windows 2016',
     }
 
 syntax_registry.reg_at(
@@ -695,6 +698,7 @@ class DomainControllerFunctionality(SelectList):
         '4': 'Windows 2008R2',
         '5': 'Windows 2012',
         '6': 'Windows 2012R2',
+        '7': 'Windows 2016',
     }
 
 syntax_registry.reg_at(
@@ -899,6 +903,7 @@ syntax_registry.reg_at(
         '1.2.840.113556.1.2.91',  # repsFrom
         '1.2.840.113556.1.2.83',  # repsTo
         '1.2.840.113556.1.2.281', # nTSecurityDescriptor
+        '2.16.840.1.113730.3.1.35',  # thumbnailPhoto
     ]
 )
 
