@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: ascii -*-
 """
 web2ldap.web.helper - Misc. stuff useful in CGI-BINs
 
-(c) 1998-2021 by Michael Stroeder <michael@stroeder.com>
+(C) 1998-2022 by Michael Stroeder <michael@stroeder.com>
 
 This software is distributed under the terms of the
 Apache License Version 2.0 (Apache-2.0)
@@ -124,7 +124,7 @@ class AcceptCharsetDict(AcceptHeaderDict):
         lst = self.items()
         while lst and lst[0][0] != '*':
             try:
-                u''.encode(lst[0][0])
+                ''.encode(lst[0][0])
             except LookupError:
                 lst.pop(0)
             else:
