@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# -*- coding: ascii -*-
 """
 web2ldapcnf.hosts - Configuration options for specific LDAP servers
 
@@ -6,7 +6,7 @@ See documentation for details:
 https://www.web2ldap.de/web2ldapcnf_hosts.html
 https://www.web2ldap.de/usability.html
 
-(c) 1998-2021 by Michael Stroeder <michael@stroeder.com>
+(C) 1998-2022 by Michael Stroeder <michael@stroeder.com>
 """
 
 # Leave these import lines alone
@@ -40,7 +40,14 @@ ldap_uri_list = [
             'ldaps://demo.ae-dir.com/ou=ae-dir????'
             'bindname=aead,X-BINDPW=CorrectHorseBatteryStaple'
         ),
-        'Æ-DIR demo role Æ admin',
+        '\xC6-DIR demo role \xC6 admin',
+    ),
+    (
+        (
+            'ldaps://demo.ae-dir.com/ou=ae-dir????'
+            'bindname=zots,X-BINDPW=CorrectHorseBatteryStaple'
+        ),
+        '\xC6-DIR demo role zone admin',
     ),
     (
         (
@@ -262,10 +269,22 @@ OPENLDAP_MONITOR_CONFIG = Web2LDAPConfig(
             '%(monitorConnectionAuthzDN)s<br>'
             '(ops r: %(monitorConnectionOpsReceived)s, e: %(monitorConnectionOpsExecuting)s, p: %(monitorConnectionOpsPending)s, c: %(monitorConnectionOpsCompleted)s)'
         ),
+        # new in OpenLDAP 2.5
+        'olmSyncReplInstance':(
+            '%(cn)s - %(olmSRSyncPhase)s<br>'
+            'Providers: %(olmSRProviderURIList)s %(olmSRConnection)s<br>'
+            'Last connect: %(olmSRLastConnect)s<br>'
+            'Last contact: %(olmSRLastContact)s<br>'
+            'Last cookie received: %(olmSRLastCookieRcvd)s<br>'
+            'Last cookie sent: %(olmSRLastCookieSent)s<br>'
+            'Next connect: %(olmSRNextConnect)s<br>'
+        ),
     },
     read_template={
         # for OpenLDAP
         'monitorConnection': os.path.join(TEMPLATES_DIR, 'read_monitorConnection.html'),
+        # new in OpenLDAP 2.5
+        'olmSyncReplInstance': os.path.join(TEMPLATES_DIR, 'read_olmSyncReplInstance.html'),
     },
 )
 
@@ -334,11 +353,11 @@ CN_CONFIG = Web2LDAPConfig(
 )
 
 #---------------------------------------------------------------------------
-# Presets for Æ-DIR
+# Presets for AE-DIR
 #---------------------------------------------------------------------------
 
 AE_DIR_CONFIG = Web2LDAPConfig(
-    description='Æ-DIR',
+    description='\xC6-DIR',
     top_template=os.path.join(TEMPLATES_DIR, 'ae-dir', 'top.html'),
     binddn_mapping='ldap:///uid={user},_??base',
     boundas_template={
@@ -369,6 +388,7 @@ AE_DIR_CONFIG = Web2LDAPConfig(
         'aeNotAfter',
         'aeNotBefore',
         'aeNwDevice',
+        'aeOwner',
         'aePasswordAdmins',
         'aePerson',
         'aeProxyFor',
@@ -385,7 +405,6 @@ AE_DIR_CONFIG = Web2LDAPConfig(
         'aeVisibleSudoers',
         'aeZoneAdmins',
         'aeZoneAuditors'
-        'authTimestamp',
         'cn',
         'createTimestamp',
         'creatorsName',
@@ -412,6 +431,7 @@ AE_DIR_CONFIG = Web2LDAPConfig(
         'loginShell',
         'macAddress',
         'mail',
+        'mailLocalAddress',
         'manager',
         'member',
         'memberOf',
@@ -451,6 +471,7 @@ AE_DIR_CONFIG = Web2LDAPConfig(
         'pwdChangedTime',
         'pwdFailureTime',
         'pwdHistory',
+        'pwdLastSuccess',
         'pwdLockout',
         'pwdMustChange',
         'pwdPolicySubentry',
@@ -608,6 +629,7 @@ AE_DIR_CONFIG = Web2LDAPConfig(
         ),
     },
     read_template={
+        'OpenLDAProotDSE': os.path.join(TEMPLATES_DIR, 'ae-dir', 'read_OpenLDAProotDSE.html'),
         'msPwdResetObject': os.path.join(TEMPLATES_DIR, 'read_msPwdResetObject.html'),
         'posixAccount': os.path.join(TEMPLATES_DIR, 'read_posixAccount.html'),
         'aePolicy': os.path.join(TEMPLATES_DIR, 'ae-dir', 'read_aePolicy.html'),
@@ -683,30 +705,31 @@ AE_DIR_CONFIG = Web2LDAPConfig(
         'aeHost':r'Host/server: <strong>%(host)s</strong>',
     },
     addform_entry_templates={
-        'Æ-DIR tag': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeTag.ldif'),
-        'Æ-DIR user group': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeGroup.ldif'),
-        'Æ-DIR mail group': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeMailGroup.ldif'),
-        'Æ-DIR primary user account': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeUser_inetLocalMailRecipient.ldif'),
-        'Æ-DIR personal user account': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeUser.ldif'),
-        'Æ-DIR OATH-HOTP token': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_oath_hotp_token.ldif'),
-        #'Æ-DIR OATH-TOTP token': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_oath_totp_token.ldif'),
-        'Æ-DIR password policy': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_pwdPolicy.ldif'),
-        'Æ-DIR OATH-HOTP parameters': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_oathHOTPParams.ldif'),
-        'Æ-DIR person': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aePerson.ldif'),
-        'Æ-DIR contact': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeContact.ldif'),
-        'Æ-DIR department': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeDept.ldif'),
-        'Æ-DIR location': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeLocation.ldif'),
-        'Æ-DIR network device': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeNwDevice.ldif'),
-        'Æ-DIR server/service group': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeSrvGroup.ldif'),
-        'Æ-DIR server/host': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeHost.ldif'),
-        'Æ-DIR service/tool account (POSIX)': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeService_posixAccount.ldif'),
-        'Æ-DIR service/tool account': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeService.ldif'),
-        'Æ-DIR zone': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeZone.ldif'),
-        'Æ-DIR zone admins group': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeGroup_zone-admins.ldif'),
-        'Æ-DIR zone auditors group': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeGroup_zone-auditors.ldif'),
-        'Æ-DIR replica account': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_slapd-replica.ldif'),
-        'Æ-DIR login proxy': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_login-proxy.ldif'),
-        'Æ-DIR sudo su - root': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeSudoRule_su_root.ldif'),
+        '\xC6-DIR tag': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeTag.ldif'),
+        '\xC6-DIR user group': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeGroup.ldif'),
+        '\xC6-DIR mail group': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeMailGroup.ldif'),
+        '\xC6-DIR primary user account': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeUser_inetLocalMailRecipient.ldif'),
+        '\xC6-DIR personal user account': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeUser.ldif'),
+        '\xC6-DIR OATH-HOTP token': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_oath_hotp_token.ldif'),
+        #'\xC6-DIR OATH-TOTP token': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_oath_totp_token.ldif'),
+        '\xC6-DIR password policy': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_pwdPolicy.ldif'),
+        '\xC6-DIR OATH-HOTP parameters': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_oathHOTPParams.ldif'),
+        '\xC6-DIR person': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aePerson.ldif'),
+        '\xC6-DIR contact': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeContact.ldif'),
+        '\xC6-DIR department': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeDept.ldif'),
+        '\xC6-DIR location': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeLocation.ldif'),
+        '\xC6-DIR network device': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeNwDevice.ldif'),
+        '\xC6-DIR server/service group': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeSrvGroup.ldif'),
+        '\xC6-DIR server/host': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeHost.ldif'),
+        '\xC6-DIR service/tool account (POSIX)': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeService_posixAccount.ldif'),
+        '\xC6-DIR service/tool account': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeService.ldif'),
+        '\xC6-DIR zone': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeZone.ldif'),
+        '\xC6-DIR zone admins group': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeGroup_zone-admins.ldif'),
+        '\xC6-DIR zone auditors group': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeGroup_zone-auditors.ldif'),
+        '\xC6-DIR replica account': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_slapd-replica.ldif'),
+        '\xC6-DIR login proxy': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_login-proxy.ldif'),
+        '\xC6-DIR sudo su - root': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeSudoRule_su_root.ldif'),
+        '\xC6-DIR sudoers entry': os.path.join(TEMPLATES_DIR, 'ae-dir', 'add_aeSudoRule.ldif'),
     },
     passwd_template=os.path.join(TEMPLATES_DIR, 'ae-dir', 'passwd.html'),
     passwd_hashtypes=('ssha', ''),
@@ -723,6 +746,10 @@ AE_DIR_CONFIG = Web2LDAPConfig(
         'member':40,
         'memberUid':40,
         'memberOf':30,
+        'allowedAttributes':2,
+        'allowedAttributesEffective':2,
+        'allowedChildClasses':2,
+        'allowedChildClassesEffective':2,
     },
     requested_attrs=(
         # Proxy Authz attributes
@@ -921,6 +948,7 @@ GLOBAL_DEFAULTS = Web2LDAPConfig(
     # HTML template file used for displaying entries of specific object class
     read_template={
         # 'object class': 'pathname of HTML template file'
+        'OpenLDAProotDSE': os.path.join(TEMPLATES_DIR, 'read_OpenLDAProotDSE.html'),
         'inetOrgPerson': os.path.join(TEMPLATES_DIR, 'read_inetOrgPerson.html'),
         'account': os.path.join(TEMPLATES_DIR, 'read_account.html'),
         'organizationalPerson': os.path.join(TEMPLATES_DIR, 'read_inetOrgPerson.html'),
@@ -1000,6 +1028,8 @@ GLOBAL_DEFAULTS = Web2LDAPConfig(
         'dhcpService': os.path.join(TEMPLATES_DIR, 'dhcp', 'inputform_dhcpService.html'),
         'dhcpSubnet': os.path.join(TEMPLATES_DIR, 'dhcp', 'inputform_dhcpSubnet.html'),
         'dNSDomain2': os.path.join(TEMPLATES_DIR, 'inputform_dNSDomain2.html'),
+        'PdnsDomain': os.path.join(TEMPLATES_DIR, 'inputform_PdnsDomain.html'),
+        'PdnsRecordData': os.path.join(TEMPLATES_DIR, 'inputform_PdnsRecordData.html'),
         'inetLocalMailRecipient': os.path.join(TEMPLATES_DIR, 'inputform_inetLocalMailRecipient.html'),
         'oathHOTPUser': os.path.join(TEMPLATES_DIR, 'oath', 'inputform_oathHOTPUser.html'),
         'oathTOTPUser': os.path.join(TEMPLATES_DIR, 'oath', 'inputform_oathTOTPUser.html'),
@@ -1101,12 +1131,6 @@ ldap_def = {
         description='My poorly configured LDAP host',
     ),
 
-    'ldap://localhost:7389': Web2LDAPConfig(
-        description='Sun/Oracle DSEE',
-        # broken schema shipped with Sun/Oracle/389 DS
-        schema_strictcheck=False,
-    ),
-
     'ldap://ipa.demo1.freeipa.org': Web2LDAPConfig(
         description='FreeIPA demo host',
         # work around 389-DS bug here
@@ -1125,21 +1149,21 @@ ldap_def = {
     # For dynamic configuration via cn=config
     'ldap:///cn=config': CN_CONFIG,
 
-    # Æ-DIR's main DB
+    # AE-DIR's main DB
     'ldap:///ou=ae-dir': AE_DIR_CONFIG,
 
-    # Æ-DIR's accesslog (override description)
+    # AE-DIR's accesslog (override description)
     'ldap:///cn=accesslog-ae-dir': OPENLDAP_ACCESSLOG_CONFIG.clone(
-        description='Æ-DIR accesslog',
+        description='\xC6-DIR accesslog',
     ),
 
-    # Æ-DIR's online demo
+    # AE-DIR's online demo
     #-----------------------------------------------------------------------
 
     # This creates a new config based on config preset instance
     # AE_DIR_CONFIG and just sets a specific description
     'ldaps://demo.ae-dir.com/ou=ae-dir': AE_DIR_CONFIG.clone(
-        description='Æ-DIR demo',
+        description='\xC6-DIR demo',
     ),
 
 }
@@ -1150,7 +1174,7 @@ ldap_def = {
 # another cloned config for setting specific LDAPS parameters for public AE-DIR demo server
 ldap_def['ldaps://demo.ae-dir.com'] = ldap_def['ldaps://demo.ae-dir.com/ou=ae-dir'].clone(
     tls_options={
-        ldap0.OPT_X_TLS_CACERTFILE: os.path.join(ETC_DIR, 'tls', 'cacerts', 'DST_Root_CA_X3.pem'),
+        ldap0.OPT_X_TLS_CACERTFILE: os.path.join(ETC_DIR, 'tls', 'cacerts', 'ISRG_Root_X1.pem'),
     },
 )
 # another cloned config for mandating use of StartTLS ext.op.
@@ -1240,7 +1264,7 @@ for ad_domain in AD_DOMAINS:
 # Local MS AD VMs
 ldap_def['ldaps://win-n2fcj0kh982.adt1.example.com'] = MSAD_CONFIG.clone(
     tls_options={
-        ldap0.OPT_X_TLS_CACERTFILE: '/home/michael/Proj/ae-dir/ansible-example-site/files/my-ae-dir-testca-2017-06.pem',
+        ldap0.OPT_X_TLS_CACERTFILE: '/home/michael/Proj/ae-dir/ansible-example-site/files/my-ae-dir-testca-2021-03.pem',
     },
 )
 
@@ -1268,7 +1292,7 @@ for aedir_host in (
     ldap_def['ldaps://{0}'.format(aedir_host)] = aedir_config_vnet1
     ldap_uri_list.append((
         'ldaps://{0}/ou=ae-dir????bindname=xkcd,X-BINDPW=Geheimer123456'.format(aedir_host),
-        '{0} as Æ admin (xkcd)'.format(aedir_host),
+        '{0} as \xC6 admin (xkcd)'.format(aedir_host),
     ))
 
 
